@@ -4,7 +4,7 @@ Coro::Channel - message queues
 
 =head1 SYNOPSIS
 
- use Coro::Channel;
+ use Coro;
 
  $q1 = new Coro::Channel <maxsize>;
 
@@ -21,6 +21,9 @@ of it from the other end. If the capacity of the Channel is maxed out
 writers will block. Both ends of a Channel can be read/written from by as
 many coroutines as you want concurrently.
 
+You don't have to load C<Coro::Channel> manually, it will be loaded
+automatically when you C<use Coro> and call the C<new> constructor.
+
 =over 4
 
 =cut
@@ -32,7 +35,7 @@ use common::sense;
 use Coro ();
 use Coro::Semaphore ();
 
-our $VERSION = 5.23;
+our $VERSION = 6.0;
 
 sub DATA (){ 0 }
 sub SGET (){ 1 }
@@ -107,7 +110,7 @@ C<shutdown> signals this fact to any consumers.
 =cut
 
 sub shutdown {
-   Coro::Semaphore::adjust $_[0][SGET], 2_000_000_000;
+   Coro::Semaphore::adjust $_[0][SGET], 1_000_000_000;
 }
 
 =item $q->size
