@@ -76,8 +76,6 @@ use common::sense;
 
 use Carp;
 
-use Time::HiRes (); # currently only used for PerlIO::cede
-
 our $DIEHOOK;
 our $WARNHOOK;
 
@@ -92,19 +90,13 @@ sub warnhook { &$WARNHOOK }
 use XSLoader;
 
 BEGIN {
-   our $VERSION = 5.24;
+   our $VERSION = 6.0;
 
    # must be done here because the xs part expects it to exist
    # it might exist already because Coro::Specific created it.
    $Coro::current ||= { };
 
-   {
-      # save/restore the handlers before/after overwriting %SIG magic
-      local $SIG{__DIE__};
-      local $SIG{__WARN__};
-
-      XSLoader::load __PACKAGE__, $VERSION;
-   }
+   XSLoader::load __PACKAGE__, $VERSION;
 
    # need to do it after overwriting the %SIG magic
    $SIG{__DIE__}  ||= \&diehook;
@@ -223,6 +215,8 @@ in the code below, and use it in your threads:
 Another way is to use dynamic winders, see C<Coro::on_enter> and
 C<Coro::on_leave> for this.
 
+Yet another way that works onyl for variables is C<< ->swap_sv >>.
+
 =item $prev->transfer ($next)
 
 Save the state of the current subroutine in C<$prev> and switch to the
@@ -231,29 +225,20 @@ thread saved in C<$next>.
 The "state" of a subroutine includes the scope, i.e. lexical variables and
 the current execution state (subroutine, stack).
 
+=item $state->throw ([$scalar])
+
 =item $state->is_new
 
-Returns true iff this Coro::State object is "new", i.e. has never been run
-yet. Those states basically consist of only the code reference to call and
-the arguments, but consumes very little other resources. New states will
-automatically get assigned a perl interpreter when they are transfered to.
+=item $state->is_zombie
 
-=item $state->is_destroyed
-
-Returns true iff the Coro::State object has been destroyed (by
-C<cancel>), i.e. it's resources freed because they were C<cancel>'d (or
-C<terminate>'d).
+See the corresponding method for L<Coro> objects. 
 
 =item $state->cancel
 
 Forcefully destructs the given Coro::State. While you can keep the
 reference, and some memory is still allocated, the Coro::State object is
-effecticely dead, destructors have been freed, it cannot be transfered to
-anymore.
-
-=item $state->throw ([$scalar])
-
-See L<< Coro->throw >>.
+effectively dead, destructors have been freed, it cannot be transfered to
+anymore, it's pushing up the daisies.
 
 =item $state->call ($coderef)
 
@@ -281,7 +266,7 @@ This (very advanced) function can be used to make I<any> variable local to
 a thread.
 
 It works by swapping the contents of C<$sv> and C<$swap_sv> each time the
-thread is entered and left again, i.e. it is similarly to:
+thread is entered and left again, i.e. it is similar to:
 
    $tmp = $sv; $sv = $swap_sv; $swap_sv = $tmp;
 
@@ -341,15 +326,25 @@ in doing so, however.
 
 =item $ncctx = Coro::State::cctx_count
 
-Returns the number of C-level coro allocated. If this number is
-very high (more than a dozen) it might help to identify points of C-level
-recursion in your code and moving this into a separate coro.
+Returns the number of C-level thread contexts allocated. If this number is
+very high (more than a dozen) it might be beneficial to identify points of
+C-level recursion (perl calls C/XS, which calls perl again which switches
+coros - this forces an allocation of a C-level thread context) in your
+code and moving this into a separate coro.
 
 =item $nidle = Coro::State::cctx_idle
 
-Returns the number of allocated but idle (free for reuse) C level
-coro. Currently, Coro will limit the number of idle/unused cctxs to
-8.
+Returns the number of allocated but idle (currently unused and free for
+reuse) C level thread contexts.
+
+=item $old = Coro::State::cctx_max_idle [$new_count]
+
+Coro caches C contexts that are not in use currently, as creating them
+from scratch has some overhead.
+
+This function returns the current maximum number of idle C contexts and
+optionally sets the new amount. The count must be at least C<1>, with the
+default being C<4>.
 
 =item $old = Coro::State::cctx_stacksize [$new_stacksize]
 
@@ -363,15 +358,6 @@ Please note that coros will only need to use a C-level stack if the
 interpreter recurses or calls a function in a module that calls back into
 the interpreter, so use of this feature is usually never needed.
 
-=item $old = Coro::State::cctx_max_idle [$new_count]
-
-Coro caches C contexts that are not in use currently, as creating them
-from scratch has some overhead.
-
-This function returns the current maximum number of idle C contexts and
-optionally sets the new amount. The count must be at least C<1>, with the
-default being C<4>.
-
 =item @states = Coro::State::list
 
 Returns a list of all states currently allocated.
