@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2009 Marc Alexander Lehmann <schmorp@schmorp.de>
+ * Copyright (c) 2001-2011 Marc Alexander Lehmann <schmorp@schmorp.de>
  * 
  * Redistribution and use in source and binary forms, with or without modifica-
  * tion, are permitted provided that the following conditions are met:
@@ -88,6 +88,11 @@ coro_init (void)
 
   coro_transfer (new_coro, create_coro);
 
+#if __linux && __amd64
+  /* we blindly assume on any __linux with __amd64 we have a new enough gas with .cfi_undefined support */
+  asm (".cfi_undefined rip");
+#endif
+
   func ((void *)arg);
 
   /* the new coro returned. bad. just abort() for now */
@@ -112,61 +117,87 @@ trampoline (int sig)
 
 # if CORO_ASM
 
+  #if _WIN32
+    #define CORO_WIN_TIB 1
+  #endif
+
   asm (
-       ".text\n"
-       ".globl coro_transfer\n"
-       ".type coro_transfer, @function\n"
+       "\t.text\n"
+       "\t.globl coro_transfer\n"
        "coro_transfer:\n"
        /* windows, of course, gives a shit on the amd64 ABI and uses different registers */
        /* http://blogs.msdn.com/freik/archive/2005/03/17/398200.aspx */
        #if __amd64
-         #define NUM_SAVED 6
-         "\tpush %rbp\n"
-         "\tpush %rbx\n"
-         "\tpush %r12\n"
-         "\tpush %r13\n"
-         "\tpush %r14\n"
-         "\tpush %r15\n"
-         #if CORO_WIN_TIB
-           "\tpush %gs:0x0\n"
-           "\tpush %gs:0x8\n"
-           "\tpush %gs:0xc\n"
+         #ifdef WIN32
+           /* TODO: xmm6..15 also would need to be saved. sigh. */
+           #define NUM_SAVED 8
+           "\tpushq %rsi\n"
+           "\tpushq %rdi\n"
+           "\tpushq %rbp\n"
+           "\tpushq %rbx\n"
+           "\tpushq %r12\n"
+           "\tpushq %r13\n"
+           "\tpushq %r14\n"
+           "\tpushq %r15\n"
+           #if CORO_WIN_TIB
+             "\tpushq %fs:0x0\n"
+             "\tpushq %fs:0x8\n"
+             "\tpushq %fs:0xc\n"
+           #endif
+           "\tmovq %rsp, (%rcx)\n"
+           "\tmovq (%rdx), %rsp\n"
+           #if CORO_WIN_TIB
+             "\tpopq %fs:0xc\n"
+             "\tpopq %fs:0x8\n"
+             "\tpopq %fs:0x0\n"
+           #endif
+           "\tpopq %r15\n"
+           "\tpopq %r14\n"
+           "\tpopq %r13\n"
+           "\tpopq %r12\n"
+           "\tpopq %rbx\n"
+           "\tpopq %rbp\n"
+           "\tpopq %rdi\n"
+           "\tpopq %rsi\n"
+         #else
+           #define NUM_SAVED 6
+           "\tpushq %rbp\n"
+           "\tpushq %rbx\n"
+           "\tpushq %r12\n"
+           "\tpushq %r13\n"
+           "\tpushq %r14\n"
+           "\tpushq %r15\n"
+           "\tmovq %rsp, (%rdi)\n"
+           "\tmovq (%rsi), %rsp\n"
+           "\tpopq %r15\n"
+           "\tpopq %r14\n"
+           "\tpopq %r13\n"
+           "\tpopq %r12\n"
+           "\tpopq %rbx\n"
+           "\tpopq %rbp\n"
          #endif
-         "\tmov  %rsp, (%rdi)\n"
-         "\tmov  (%rsi), %rsp\n"
-         #if CORO_WIN_TIB
-           "\tpop  %gs:0xc\n"
-           "\tpop  %gs:0x8\n"
-           "\tpop  %gs:0x0\n"
-         #endif
-         "\tpop  %r15\n"
-         "\tpop  %r14\n"
-         "\tpop  %r13\n"
-         "\tpop  %r12\n"
-         "\tpop  %rbx\n"
-         "\tpop  %rbp\n"
        #elif __i386
          #define NUM_SAVED 4
-         "\tpush %ebp\n"
-         "\tpush %ebx\n"
-         "\tpush %esi\n"
-         "\tpush %edi\n"
+         "\tpushl %ebp\n"
+         "\tpushl %ebx\n"
+         "\tpushl %esi\n"
+         "\tpushl %edi\n"
          #if CORO_WIN_TIB
-           "\tpush %fs:0\n"
-           "\tpush %fs:4\n"
-           "\tpush %fs:8\n"
+           "\tpushl %fs:0\n"
+           "\tpushl %fs:4\n"
+           "\tpushl %fs:8\n"
          #endif
-         "\tmov  %esp, (%eax)\n"
-         "\tmov  (%edx), %esp\n"
+         "\tmovl %esp, (%eax)\n"
+         "\tmovl (%edx), %esp\n"
          #if CORO_WIN_TIB
-           "\tpop  %fs:8\n"
-           "\tpop  %fs:4\n"
-           "\tpop  %fs:0\n"
+           "\tpopl %fs:8\n"
+           "\tpopl %fs:4\n"
+           "\tpopl %fs:0\n"
          #endif
-         "\tpop  %edi\n"
-         "\tpop  %esi\n"
-         "\tpop  %ebx\n"
-         "\tpop  %ebp\n"
+         "\tpopl %edi\n"
+         "\tpopl %esi\n"
+         "\tpopl %ebx\n"
+         "\tpopl %ebp\n"
        #else
          #error unsupported architecture
        #endif
@@ -212,8 +243,8 @@ coro_create (coro_context *ctx, coro_func coro, void *arg, void *sptr, long ssiz
     }
 
   /* set the new stack */
-  nstk.ss_sp    = STACK_ADJUST_PTR (sptr,ssize); /* yes, some platforms (IRIX) get this wrong. */
-  nstk.ss_size  = STACK_ADJUST_SIZE (sptr,ssize);
+  nstk.ss_sp    = STACK_ADJUST_PTR (sptr, ssize); /* yes, some platforms (IRIX) get this wrong. */
+  nstk.ss_size  = STACK_ADJUST_SIZE (sptr, ssize);
   nstk.ss_flags = 0;
 
   if (sigaltstack (&nstk, &ostk) < 0)
@@ -307,6 +338,7 @@ coro_create (coro_context *ctx, coro_func coro, void *arg, void *sptr, long ssiz
   #endif
 
   ctx->sp -= NUM_SAVED;
+  memset (ctx->sp, 0, sizeof (*ctx->sp) * NUM_SAVED);
 
 # elif CORO_UCONTEXT
 
@@ -404,7 +436,12 @@ coro_create (coro_context *ctx, coro_func coro, void *arg, void *sptr, long ssiz
       args.main = &nctx;
 
       pthread_attr_init (&attr);
+#if __UCLIBC__
+      /* exists, but is borked */
+      /*pthread_attr_setstacksize (&attr, (size_t)ssize);*/
+#else
       pthread_attr_setstack (&attr, sptr, (size_t)ssize);
+#endif
       pthread_attr_setscope (&attr, PTHREAD_SCOPE_PROCESS);
       pthread_create (&ctx->id, &attr, coro_init, &args);
 
